Method: RSpec::Core::Example#location

Defined in:
lib/rspec/core/example.rb

#locationString

Returns the exact source location of this example in a form like ./path/to/spec.rb:17.

Returns:

  • (String)

    the exact source location of this example in a form like ./path/to/spec.rb:17



62
# File 'lib/rspec/core/example.rb', line 62

 :location