Method: RSpec::Core::Formatters::BaseFormatter#start_dump

Defined in:
lib/rspec/core/formatters/base_formatter.rb

#start_dumpObject

This method is invoked after all of the examples have executed. The next method to be invoked after this one is #dump_failure (once for each failed example),



79
80
# File 'lib/rspec/core/formatters/base_formatter.rb', line 79

def start_dump
end