Method: RSpec::Core::Formatters::Protocol#start
- Defined in:
- lib/rspec/core/formatters/protocol.rb
#start(notification) ⇒ void
This method is invoked before any examples are run, right after they have all been collected. This can be useful for special formatters that need to provide progress on feedback (graphical ones).
This will only be invoked once, and the next one to be invoked is #example_group_started.
|
|
# File 'lib/rspec/core/formatters/protocol.rb', line 25
|