Method: RSpec::Core::MultipleExceptionError#summary

Defined in:
lib/rspec/core/formatters/exception_presenter.rb

#summaryString

Returns A summary of the failure, including the block label and a count of failures.

Returns:

  • (String)

    A summary of the failure, including the block label and a count of failures.



540
541
542
# File 'lib/rspec/core/formatters/exception_presenter.rb', line 540

def summary
  "Got #{exception_count_description}"
end