Method: RSpec::Core::Notifications::SummaryNotification#formatted_load_time

Defined in:
lib/rspec/core/notifications.rb

#formatted_load_timeString

Returns a formatted version of the time it took to boot RSpec and load the spec files.

Returns:

  • (String)

    a formatted version of the time it took to boot RSpec and load the spec files



380
381
382
# File 'lib/rspec/core/notifications.rb', line 380

def formatted_load_time
  Formatters::Helpers.format_duration(load_time)
end