Method: RSpec::Core::Formatters::Protocol#close
- Defined in:
- lib/rspec/core/formatters/protocol.rb
#close(notification) ⇒ void
Invoked at the end of a suite run. Allows the formatter to do any tidying up, but be aware that formatter output streams may be used elsewhere so don't actually close them.
|
|
# File 'lib/rspec/core/formatters/protocol.rb', line 170
|