Method: RSpec::Core::Formatters::Protocol#example_group_started
- Defined in:
- lib/rspec/core/formatters/protocol.rb
#example_group_started(notification) ⇒ void
This method is invoked at the beginning of the execution of each example group.
The next method to be invoked after this is #example_passed, #example_pending, or #example_group_finished.
|
|
# File 'lib/rspec/core/formatters/protocol.rb', line 38
|