Method: RSpec::Core::Configuration#backtrace_exclusion_patterns
- Defined in:
- lib/rspec/core/configuration.rb
#backtrace_exclusion_patterns ⇒ Array<Regexp>
Regexps used to exclude lines from backtraces.
Excludes lines from ruby (and jruby) source, installed gems, anything in any "bin" directory, and any of the RSpec libs (outside gem installs) by default.
You can modify the list via the getter, or replace it with the setter.
To override this behaviour and display a full backtrace, use
--backtrace on the command line, in a .rspec file, or in the
rspec_options attribute of RSpec's rake task.
697 698 699 |
# File 'lib/rspec/core/configuration.rb', line 697 def backtrace_exclusion_patterns @backtrace_formatter.exclusion_patterns end |